#!/usr/bin/env python
# -*- coding: iso-8859-15 -*-
''' wmgmail Gmail mail choosing dialog

Copyright  2004 Pasi Savolainen <pasi.savolainen@iki.fi>

Licensed under the GNU General Public License.
'''

import gtk.glade
import re
import wmgsettings
import os
import sys

default_msg = "16 of 33 - Aug 4 <b>customerservice</b>\n" \
"<b>Welcome to Gmail.com</b>\n" \
"<i>Dear Foobar, Thank you for registering at Gmail.com. " \
"Your account is now active. Please ...</i>";

class NoMessage:
    def __getattr__(self, name):
        return "no message"

class GmailChooser:
    def __init__(self, unreadMails):
        # allow this python script access to the .glade file
        self.wtree = gtk.glade.XML( wmgsettings.get_glade_fname(), 'mailchooser')
        # Connect the glade signals to the python callbacks
        self.wtree.signal_autoconnect(self)
        self.setup_dialog(unreadMails)


    def setup_dialog(self, unreadMails):
        logo = self.wtree.get_widget('logo')
        logo.set_from_file( wmgsettings.get_data_fname('gmail-newmail.png'))
        ilmot = self.wtree.get_widget('maillist')
        for i in ilmot.get_children():
            ilmot.remove(i)
        if not len(unreadMails):
            unreadMails=[NoMessage()]
        for mail in unreadMails:
            self.add_mail(mail)

    def demunge(self, s):
        s = s.decode('UTF-8').replace('\<', '<').replace('\>','>').replace('&hellip;','..')
        s = re.sub(r'<span[^>]*>|</span>', '', s)
        s = re.sub(r'<font[^>]*>|</font>', '', s)
        return s

    def add_mail(self, mail):
        date = self.demunge(mail.date)
        authors = self.demunge(mail.authors)
        subject = self.demunge(mail.subject)
        snippet = self.demunge(mail.snippet)
        categories = ""
        for i in mail.categories:
            if i != '^i':
                categories += " " + i;
        self.add_message("%(date)s -- %(authors)s %(categories)s\n"
                         "%(subject)s\n<i>%(snippet)s</i>" % locals(),
                         mail)

    def add_message(self, msg, mail):
        
        label = gtk.Label(msg);
        label.set_line_wrap(True)
        label.set_alignment(0.1, 0.1)
        label.set_markup(msg)

        button = gtk.Button();
        button.set_relief(gtk.RELIEF_NONE)
        button.add(label)
        button.connect("clicked", self.button_clicked, mail);
        button.connect("button-press-event", self.button_pressed, mail);
        
        ilmot = self.wtree.get_widget('maillist')
        ilmot.pack_start(button, expand=False, fill=False)
        button.show_all()

    def button_clicked(self, widget, data=None):
        #print "Suap dataa %s" % data
        if os.fork():
            # fork and return if not child.
            # shut down the UI.
            gtk.main_quit()
            return
        cmd = wmgsettings.getwmgmailsettings(wmgsettings.get_settingsfname())['browser_command']
        cmd = cmd.replace('%s', 'http://gmail.google.com/gmail')
        os.execl(*['/bin/sh', '/bin/sh', '-c', cmd])

    def button_pressed(self, widget, event, data=None):
        # print "Button press %s %s" % (event, data)
        if 0 and event.button == 3:
            menu = (
                ("/Eka", None, None, 0, "<Branch>"),
                ("/Eka/Toka", None, None, 0, None),
                ("/Eka/Koli", None, None, 0, None),
                ("/Viis", None, None, 0, None))
            ag = gtk.AccelGroup()
            itemf =  gtk.ItemFactory(gtk.Menu, "<main>", ag)
            itemf.create_items(menu);
            self.pmenu = itemf.get_widget("<main>")
            self.pmenu.popup(None,None,None,event.button,event.time)
                
            print "rightie";
            
    def show_dialog(self):
        ds = self.wtree.get_widget('mailchooser')
        ds.show()
        
    def on_close_clicked(self, *args):
        # print "kankeli"
        gtk.main_quit();
        
    def on_add_clicked(self, *args):
        # print "appeli"
        self.add_message(default_msg)


def run_in_thread(unreadMails):
    gmc = GmailChooser(unreadMails)
    gmc.show_dialog()
    gtk.main()

def main():
    wmgs = uikoe()
    wmgs.show_dialog()
    gtk.main()

if __name__ == '__main__':
    main()
