#!/usr/bin/env python
# -*- coding: iso-8859-15 -*-
''' wmgmail Gmail mail choosing dialog

Copyright  2004 Pasi Savolainen <pasi.savolainen@iki.fi>

Licensed under the GNU General Public License.
'''

import gtk.glade
import re
import wmgsettings
import os
import sys

TIMEOUT_STEP = 100

class NoMessage:
    def __getattr__(self, name):
        answers = { 'date': "Right now",
                    'authors': "Your Friendly wmgmail",
                    'subject': "You seem to have no mail",
                    'snippet': "There really seems to be no mail",
                    'categories': ""}
        # print "asked for %s" % name
        return answers[name]

class GmailChooser:
    def __init__(self, unreadMails, popup):
        # allow this python script access to the .glade file
        self.wtree = gtk.glade.XML( wmgsettings.get_glade_fname(), 'mailchooser')
        # Connect the glade signals to the python callbacks
        self.wtree.signal_autoconnect(self)
        self.setup_dialog(unreadMails)
        if popup and wmgsettings.get_param('pop_qmp_timeouts'):
            self.setup_progress(wmgsettings.get_param('qmp_timeout'))
        

    def setup_progress(self, timeout):
        timeout = float(timeout)
        if timeout < 1:
            timeout = 5 # sanity check
        self.progress_start = timeout; # seconds, that is.
        self.progress = timeout; 
        gtk.timeout_add( TIMEOUT_STEP, self.on_progressbar_timeout, TIMEOUT_STEP);
        self.progressbar = self.wtree.get_widget('progressbar');
        self.wtree.get_widget('eventbox1').show()
        self.wtree.get_widget('keep').show()
        
    def setup_dialog(self, unreadMails):
        logo = self.wtree.get_widget('logo')
        logo.set_from_file( wmgsettings.get_data_fname('gmail-newmail.png'))
        ilmot = self.wtree.get_widget('maillist')
        for i in ilmot.get_children():
            ilmot.remove(i)
        if not len(unreadMails):
            unreadMails=[NoMessage()]
        for mail in unreadMails:
            self.add_mail(mail)

    def demunge(self, s):
        s = s.decode('UTF-8').replace('\<', '<').replace('\>','>').replace('&hellip;','..')
        s = re.sub(r'<span[^>]*>|</span>', '', s)
        s = re.sub(r'<font[^>]*>|</font>', '', s)
        return s

    def add_mail(self, mail):
        date = self.demunge(mail.date)
        authors = self.demunge(mail.authors)
        subject = self.demunge(mail.subject)
        snippet = self.demunge(mail.snippet)
        categories = ""
        for i in mail.categories:
            if i != '^i':
                categories += " " + i;
        self.add_message("%(date)s -- %(authors)s %(categories)s\n"
                         "%(subject)s\n<i>%(snippet)s</i>" % locals(),
                         mail)

    def add_message(self, msg, mail):
        
        label = gtk.Label(msg);
        label.set_line_wrap(True)
        label.set_alignment(0.1, 0.1)
        label.set_markup(msg)

        button = gtk.Button();
        button.set_relief(gtk.RELIEF_NONE)
        button.add(label)
        button.connect("clicked", self.button_clicked, mail);
        #button.connect("button-press-event", self.button_pressed, mail);
        
        ilmot = self.wtree.get_widget('maillist')
        ilmot.pack_start(button, expand=False, fill=False)
        button.show_all()

    def button_clicked(self, widget, data=None):
        #print "Suap dataa %s" % data
        if os.fork():
            # fork and return if not child.
            # shut down the UI.
            gtk.main_quit()
            return
        cmd = wmgsettings.getwmgmailsettings(wmgsettings.get_settingsfname())['browser_command']
        cmd = cmd.replace('%s', 'http://gmail.google.com/gmail')
        os.execl(*['/bin/sh', '/bin/sh', '-c', cmd])

    def button_pressed(self, widget, event, data=None):
        # print "Button press %s %s" % (event, data)
        if 0 and event.button == 3:
            menu = (
                ("/Eka", None, None, 0, "<Branch>"),
                ("/Eka/Toka", None, None, 0, None),
                ("/Eka/Koli", None, None, 0, None),
                ("/Viis", None, None, 0, None))
            ag = gtk.AccelGroup()
            itemf =  gtk.ItemFactory(gtk.Menu, "<main>", ag)
            itemf.create_items(menu);
            self.pmenu = itemf.get_widget("<main>")
            self.pmenu.popup(None,None,None,event.button,event.time)
            print "rightie";
            
    def show_dialog(self):
        self.wtree.get_widget('mailchooser').show()
        
    def on_close_clicked(self, *args):
        gtk.main_quit();
        

    def on_keep_clicked(self, *args):
        ''' Cancel undisplaying '''
        # remove extras.        
        self.wtree.get_widget('eventbox1').hide()
        self.wtree.get_widget('keep').hide()
        # nullify timeout callback.
        self.progress_start = 0
        # print "okc"
        
    def on_progressbar_timeout(self, timeout, *args):
        # print args
        # print "tick th bar %s %s" % (self.progress, self.progress_start)
        if self.progress_start == 0:
            # not sensible.
            return gtk.FALSE
        if self.progressbar.get_fraction() < 0.01:
            # print "fire in the whole"
            gtk.main_quit();
            return gtk.FALSE
        self.progress -= timeout/1000.0 # get timeout in seconds.
        self.progressbar.set_fraction(self.progress/self.progress_start)
        # Ugly shifting. (better with fixed progressbar width)
        self.progressbar.set_text("%ds" % (self.progress))
        return gtk.TRUE


def run_in_thread(unreadMails, popup):
    gmc = GmailChooser(unreadMails, popup)
    gmc.show_dialog()
    gtk.main()

def main():
    wmgs = GmailChooser([], 1)
    wmgs.show_dialog()
    gtk.main()

if __name__ == '__main__':
    main()
