#!/usr/bin/env python

''' wmgmail settings GUI

Using pygtk, setup config file for wmgmail.

Copyright (C) 2004 Pasi Savolainen <pasi.savolainen@iki.fi>

Licensed under the GNU General Public License.

'''
import gtk.glade
import wmgsettings

# interval lookup in minutes.
INTERVAL = [ 2, 5, 15, 30, 1*60, 2*60, 3*60, 24*60 ]

class wmgmailsettings:
    def __init__(self, settings_fname):
        # allow this python script access to the .glade file (foo.glade)
        self.wtree = gtk.glade.XML( wmgsettings.get_glade_fname(), 'setup_dialog')
        # Connect the glade signals to the python callbacks
        self.wtree.signal_autoconnect(self)
        self.settings_fname = settings_fname
        self.settings = wmgsettings.getwmgmailsettings(self.settings_fname)
        self.setup_dialog()

    def min2index(self, minutes):
        # umm. problematic.
        # dist = reduce(lambda x, y: min(abs(x), abs(y-minutes)), INTERVAL, INTERVAL[0]-val)
        try: index = INTERVAL.index(int(minutes));
        except ValueError: index = 1; # default to 5 min.
        return index;
    
    def index2min(self, index):
        return INTERVAL[index];

    def setup_dialog(self):
        username = self.settings['username']
        password = self.settings['password']
        check_interval = self.min2index(self.settings['check_interval'])
        browser_command = self.settings['browser_command']
        pop_qmp = self.settings['pop_qmp']
        pop_qmp_timeouts = self.settings['pop_qmp_timeouts']
        qmp_timeout = self.settings['qmp_timeout']
        exec_on_newmail = self.settings['exec_on_newmail']
        exec_command = self.settings['exec_command']        
        self.wtree.get_widget('username').set_text(username)
        self.wtree.get_widget('password').set_text(password)
        self.wtree.get_widget('check_interval').set_active(check_interval)
        self.wtree.get_widget('browser_command').set_text(browser_command)
        self.wtree.get_widget('pop_qmp').set_active(pop_qmp)
        self.wtree.get_widget('check_pop_qmp_timeout').set_active(pop_qmp_timeouts)
        self.wtree.get_widget('spin_qmp_timeout').set_value(float(qmp_timeout))
        self.wtree.get_widget('check_exec').set_active(exec_on_newmail)
        self.wtree.get_widget('exec_command').set_text(exec_command)

    def save_settings(self):
        self.settings['username'] = self.wtree.get_widget('username').get_text()
        self.settings['password'] = self.wtree.get_widget('password').get_text()
        self.settings['check_interval'] = self.index2min(self.wtree.get_widget('check_interval').get_active())
        self.settings['browser_command'] = self.wtree.get_widget('browser_command').get_text()

        self.settings['pop_qmp'] = self.wtree.get_widget('pop_qmp').get_active()
        self.settings['pop_qmp_timeouts'] = self.wtree.get_widget('check_pop_qmp_timeout').get_active()
        self.settings['qmp_timeout'] = self.wtree.get_widget('spin_qmp_timeout').get_value()
        self.settings['exec_on_newmail'] = self.wtree.get_widget('check_exec').get_active()
        self.settings['exec_command'] = self.wtree.get_widget('exec_command').get_text()
        wmgsettings.setwmgmailsettings(self.settings_fname, self.settings)

    def refresh_wmgmail(self):
        # print "attempting wmgmail refresh"
        import os, signal
        ppid = os.getppid()
        if __name__ != '__main__':
            # don't kill when debugging :)
            os.kill(ppid, signal.SIGHUP);
        
    def show_dialog(self):
        ds = self.wtree.get_widget('setup_dialog')
        ds.show()
        
    def on_cancelbutton1_clicked(self, *args):
        # print "kankeli"
        gtk.main_quit();
        
    def on_applybutton1_clicked(self, *args):
        # print "appeli"
        self.save_settings()
        self.refresh_wmgmail()
        
    def on_okbutton1_clicked(self, *args):        
        self.on_applybutton1_clicked( *args )
        gtk.main_quit()

def run_in_thread():
    #gtk.threads_init()
    #gtk.threads_enter()
    wmgs = wmgmailsettings(wmgsettings.get_settingsfname())
    wmgs.show_dialog();
    gtk.main()
    #gtk.threads_leave();
    
    

def main():
    wmgs = wmgmailsettings('wmgmail.conf')
    wmgs.show_dialog()
    gtk.main()

if __name__ == '__main__':
    main()
